@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5.0.8/mozilla/mail/components/preferences/downloads.js"
+//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/components/preferences/downloads.js"
 
 var gDownloadsPane = {
   chooseFolder: function ()
@@ -57,8 +57,15 @@ var gDownloadsPane = {
   
   _getSpecialFolderKey: function (aFolderType)
   {
-//@line 104 "/usr/obj/ports/mozilla-thunderbird-1.5.0.8/mozilla/mail/components/preferences/downloads.js"
+    if (aFolderType == "Desktop")
+      return "Desk";
+
+    if (aFolderType != "Downloads")
+      throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
+
+//@line 107 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/components/preferences/downloads.js"
     return "Home";
+//@line 110 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/components/preferences/downloads.js"
   },
 
   _getDownloadsFolder: function (aFolder)
